@@ -6,8 +6,10 @@ DATABASES = {
 }
 
 import markdown
+from django.utils.html import escape, linebreaks, urlize
 from docutils.core import publish_parts
 
+
 def render_rest(markup):
     parts = publish_parts(source=markup, writer_name="html4css1")
     return parts["fragment"]
@@ -15,6 +17,7 @@ def render_rest(markup):
 MARKUP_FIELD_TYPES = [
     ('markdown', markdown.markdown),
     ('ReST', render_rest),
+    ('plain', lambda markup: urlize(linebreaks(escape(markup)))),
 ]
 
 INSTALLED_APPS = (
